@@ -94,6 +94,26 @@ class QualityControlChart:
             ax.axhline(self.limits.UCL[0], color='black', linestyle='--')
             ax.set_yticks([self.limits.LCL[0], self.limits.UCL[0], self.center])
             ax.set_yticklabels(['LCL', 'UCL', 'CL'])
+        else:
+            # calculate mid-points for steps
+            delta = (df.x.values[1:] - df.x.values[:-1]) / 2
+            delta = [delta[0], *delta, delta[-1]]
+            lcl = [[], []]
+            ucl = [[], []]
+            last = None
+            for xleft, xright, l, u in zip(df.x.values - delta[:-1], df.x.values + delta[1:],
+                                           self.limits.LCL, self.limits.UCL):
+                if last:
+                    lcl[0].extend([xleft, xleft])
+                    lcl[1].extend([last, l])
+                    ucl[0].extend([xleft, xleft])
+                    ucl[1].extend([last, u])
+                lcl[0].extend([xleft, xright])
+                lcl[1].extend([l, l])
+                ucl[0].extend([xleft, xright])
+                ucl[1].extend([u, u])
+            ax.plot(*lcl, color='black', linestyle='--')
+            ax.plot(*ucl, color='black', linestyle='--')
 
         fig = ax.get_figure()
         fig.subplots_adjust(bottom=0.2)
